USCA-DC Recordings for May, 2014

Oral Argument Recordings
U.S. Court of Appeals for the D.C. Circuit
Advanced Search
Menu

- USCA-DC Home
- Most Recent
- Browse by Date
- Today
- This Week
- Last Week
- This Month
- Last Month
- Subscribe
- About RSS Feeds

Recordings from May,
Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec

05/19/2014
13-5281
46.7 Mb
American Meat Institute v. AGRI
Judges: Garland, Chief Judge, Henderson*, Rogers, Tatel, Brown, Griffith**, Kavanaugh, Srinivasan, Srinivasan, Pillard, Wilkins, Circuit Judges, and Williams, Senior Circuit Judge *Judge Henderson will participate by teleconference. **Judge Griffith will consider this case based on the audio recording of oral argument.
Arguing: Catherine E. Stetson, Daniel Tenny (DOJ)
05/19/2014
05/13/2014
13-1122
16.7 Mb
Sorenson Communications Inc. v. FCC
Judges: Brown, Griffith, Millett
Arguing: Christopher J. Wright, C. Grey Pash, Jr. (FCC)
05/13/2014
13-5112
21.2 Mb
USA v. Bank of America Corporation
Judges: Brown, Griffith, Millett
Arguing: Douglas W. Baruch, Lindsey Powell (DOJ)
05/13/2014
13-7086
No Recording
Deborah Peterson v. Islamic Republic of Iran
Judges: Brown, Griffith, Millett
05/13/2014
05/12/2014
08-1144
21.7 Mb
Sierra Club v. EPA
Judges: Henderson, Millett, Sentelle
Arguing: Khushi K. Desai, Norman L. Rave, Jr. (DOJ), Thomas Sayre Llewellyn
05/12/2014
13-7114
10.2 Mb
Board of County Commissioners v. FHFA
Judges: Henderson, Millett, Sentelle
Arguing: Warren T. Burns, Michael A.F. Johnson
05/12/2014
98-1379
17.1 Mb
Nat Rescr Def Cncl v. EPA
Judges: Henderson, Millett, Sentelle
Arguing: James S. Pew, Norman L. Rave, Jr. (DOJ), Michael Steinberg
05/12/2014
05/09/2014
12-7122
15.9 Mb
Ayanna Blue v. DC Public Schools
Judges: Garland, Srinivasan, Pillard
Arguing: Natalie Baughman, Carl J. Schifferle (OAG)
05/09/2014
13-1033
21.3 Mb
Southwestern Power Admin. v. FERC
Judges: Garland, Srinivasan, Pillard
Arguing: Henry C. Whitaker (DOJ), Lona Perry (FERC)
05/09/2014
13-7041
No Recording
Kathryn Campbell v. American International Group
Judges: Garland, Srinivasan, Pillard
05/09/2014
05/08/2014
13-3066
21 Mb
USA v. Paul Hite
Judges: Rogers, Pillard, Wilkins
Arguing: Lawrence S. Robbins, Patricia Heffernan (AUSA)
05/08/2014
13-5202
17.2 Mb
Matt Sissel v. HHS
Judges: Rogers, Pillard, Wilkins
Arguing: Timothy Sandefur, Alisa B. Klein (DOJ)
05/08/2014
13-5368
33.4 Mb
Priests For Life v. HHS
Judges: Rogers, Pillard, Wilkins
Arguing: Robert Joseph Muise, Noel J. Francisco, Mark B. Stern (DOJ)
05/08/2014
05/07/2014
13-5044
12.1 Mb
David Cantu v. USA
Judges: Tatel, Griffith, Pillard
Arguing: Laura Ferguson, Charles W. Scarborough (DOJ)
05/07/2014
13-5176
15.4 Mb
All Party Parliamentary Group v. Department of Defense
Judges: Tatel, Griffith, Pillard
Arguing: Dominic Perella, Charles W. Scarborough (DOJ)
05/07/2014
13-7105
12.7 Mb
USA v. Philip Morris USA Inc.
Judges: Tatel, Griffith, Pillard
Arguing: United States of America, ex rel. Anthony Oliver, Appellant v. Philip Morris USA Inc., a Virginia Corporation formerly as Philip Morris, Inc.
05/07/2014
14-5055
24.8 Mb
In re: Kellogg Brown & Root, Inc., et al., Petitioners
Judges: Griffith, Kavanaugh, Srinivasan
Arguing: John P. Elwood, Stephen M. Kohn
05/07/2014
05/06/2014
01-7041
14.8 Mb
McKesson Corp. v. Islam Repub Iran
Judges: Henderson, Rogers, Tatel
Arguing: Patrick P. O'Donnell, Mark N. Bravin
05/06/2014
13-1014
18.2 Mb
Sierra Club v. EPA
Judges: Henderson, Rogers, Tatel
Arguing: Thomas Cmar, Norman L. Rave, Jr. (DOJ), Norman W. Fichthorn
05/06/2014
13-5200
10 Mb
Prime Time International Comp v. AGRI
Judges: Henderson, Rogers, Tatel
Arguing: Jerry Stouck, Sydney Foster (DOJ)
05/06/2014
05/05/2014
13-3030
No Recording
Sealed Case
Judges: Henderson, Brown, Wilkins
05/05/2014
13-5315
26.3 Mb
Ralls Corporation v. Committee on Foreign Invest
Judges: Henderson, Brown, Wilkins
Arguing: Paul D. Clement, Douglas N. Letter (DOJ)
05/05/2014
13-7063
14.7 Mb
Tonia Edwards v. DC
Judges: Henderson, Brown, Wilkins
Arguing: Robert J. McNamara, Mary L. Wilson (OAG)
05/05/2014
05/02/2014
13-1060
53.7 Mb
POM Wonderful LLC v. FTC
Judges: Garland, Srinivasan, Ginsburg
Arguing: Thomas C. Goldstein, Jonathan E. Nuechterlein (FTC)
05/02/2014
13-3039
14.4 Mb
USA v. Yarcy Razo-Nunez
Judges: Garland, Srinivasan, Ginsburg
Arguing: Rosanna M. Taormina (FPD), Peter S. Smith (AUSA)
05/02/2014
13-5192
No Recording
Alec L. v. Gina McCarthy
Judges: Garland, Srinivasan, Ginsburg
05/02/2014
05/01/2014
12-1481
19.9 Mb
Minisink Residents for Enviro. v. FERC
Judges: Kavanaugh, Millett, Wilkins
Arguing: Carolyn Elefant, Karin L. Larson (FERC), Aaron M. Streett
05/01/2014
13-5301
34.5 Mb
Fogo de Chao (Holdings) Inc. v. Dept. of Homeland Security
Judges: Kavanaugh, Millett, Wilkins
Arguing: Carl W. Hampe, Gisela A. Westwater (DOJ)
05/01/2014
13-7092
11.4 Mb
Dan Sarfati v. Antigua and Barbuda
Judges: Kavanaugh, Millett, Wilkins
Arguing: Daniel B. Rogers, Conrad Alphonzo Airall
05/01/2014
No Recordings were found.

Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec